@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Bjoern Erik Nilsen & Fredrik Berg Kjoelstad     *
- *   bjoern.nilsen@bjoernen.com     & fredrikbk@hotmail.com                *
+ *   Copyright (C) 2005-2008 by Bjoern Erik Nilsen & Fredrik Berg Kjoelstad*
+ *   bjoern.nilsen@bjoernen.com & fredrikbk@hotmail.com                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -25,31 +25,61 @@
 #include <QDir>
 #include <QTranslator>
 #include <QLocale>
+#include <QLatin1String>
 
 
+#include <QDebug>
 LanguageHandler::LanguageHandler(QObject *parent, QApplication *stApp, const char *name) 
 	: QObject(parent)
 {
 	qmPath = QString(stopmotion::translationsDirectory);
 	activeAction = 0;
 	translator = new QTranslator(this);
-	
-	const char *localePtr = QLocale::system().name().toLatin1().constData();
-	const char *languagePref = PreferencesTool::get()->getPreference("language", localePtr);
-	QString locale(languagePref);
 
-	if ( !locale.startsWith("en") ) {
-		Logger::get().logDebug("Loading translator: ");
-		Logger::get().logDebug(locale.toLatin1().constData());
-		translator->load( "stopmotion_" + locale, qmPath);
-	}
-	
+        // Get system locale.
+        QString locale = QLocale::system().name().toLower();
+        if (locale == QLatin1String("nb_no"))
+            locale = QLatin1String("no_nb");
+        else if (locale == QLatin1String("nn_no"))
+            locale = QLatin1String("no_nn");
+        else if (locale == QLatin1String("se_no"))
+            locale = QLatin1String("no_se");
+        else
+            locale.truncate(2);
+
+        // Put together a translation file based on the qmPath or keep
+        // it empty if the locale is english.
+        const bool englishLocale = (locale == QLatin1String("en"));
+        const QString prefix = qmPath + QLatin1Char('/') + QLatin1String("stopmotion_");
+        QString translationFile = englishLocale ? QString() : prefix + locale;
+
+        if (!englishLocale && !QFile::exists(translationFile + QLatin1String(".qm"))) {
+            // Was not able to find a translation file for the locale, so use the
+            // language saved in the preferences file, or use English as fall-back.
+            const QByteArray localeArray = locale.toLatin1();
+            const char *localePtr = localeArray.constData();
+            const char *languagePref = PreferencesTool::get()->getPreference("language", localePtr);
+            if (languagePref) {
+                translationFile = prefix + QLatin1String(languagePref);
+                if (!QFile::exists(translationFile + QLatin1String(".qm")))
+                    translationFile = QString();
+	        if (strcmp(languagePref, localePtr) != 0)
+		    xmlFree((xmlChar*)languagePref);
+            } else {
+                translationFile = QString();
+            }
+        } else {
+	    PreferencesTool::get()->setPreference("language", locale.toLatin1().constData());
+        }
+
+        if (!translationFile.isEmpty()) {
+            Logger::get().logDebug("Loading translator: ");
+            Logger::get().logDebug(translationFile.toLatin1().constData());
+            translator->load(translationFile);
+        }
+
 	stApp->installTranslator(translator);
 	setObjectName(name);
-	
-	if (strcmp(languagePref, localePtr) != 0) {
-		xmlFree((xmlChar*)languagePref);
-	}
 }
 
 
