@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Bjoern Erik Nilsen & Fredrik Berg Kjoelstad     *
- *   bjoern.nilsen@bjoernen.com     & fredrikbk@hotmail.com                *
+ *   Copyright (C) 2005-2008 by Bjoern Erik Nilsen & Fredrik Berg Kjoelstad*
+ *   bjoern.nilsen@bjoernen.com & fredrikbk@hotmail.com                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -273,6 +273,12 @@ public:
 	 * @return the project file if it's setted, NULL otherwise.
 	 */
 	virtual const char* getProjectFile() = 0;
+    
+	/**
+	 * Abstract function for retrieving the project path.
+	 * @return the project path if it's setted, NULL otherwise.
+	 */
+        virtual const char* getProjectPath() = 0;
 	
 	/**
 	 * Abstract function for opening a project.
