@@ -45,6 +45,7 @@
 
 #include <cstdlib>
 #include <iostream>
+#include <unistd.h>
 
 using namespace std;
 using namespace Qt;
@@ -101,8 +102,8 @@ MainWindowGUI::MainWindowGUI(QApplication *stApp)
 	changeMonitor       = 0; 
 	lastVisitedDir      = 0;
 	
-	lastVisitedDir = new char[256];
-	strcpy( lastVisitedDir, getenv("PWD") );
+	lastVisitedDir = new char[PATH_MAX];
+	strncpy( lastVisitedDir, getenv("PWD"), PATH_MAX );
 	
 	centerWidget = new QWidget;
 	centerWidget->setObjectName("CenterWidget");
@@ -294,7 +295,7 @@ void MainWindowGUI::createActions()
 	quitAct = new QAction(this);
 	quitAct->setIcon(QIcon(quiticon));
 	quitAct->setShortcut(ControlModifier+Key_Q);
-	connect(quitAct, SIGNAL(triggered()), qApp, SLOT(quit()));
+	connect(quitAct, SIGNAL(triggered()), this, SLOT(quitProgram()));
 	
 	//Edit menu
 	undoAct = new QAction(this);
@@ -567,7 +568,7 @@ void MainWindowGUI::retranslateHelpText()
 			tr("<h4>Save</h4> "
 			"<p><em>Saves</em> the current animation as a Stopmotion "
 			"project file. <BR>If this project has been saved before it will "
-			"automaticly be saved to the previously selected file.</p>");
+			"automatically be saved to the previously selected file.</p>");
 	saveAct->setWhatsThis(infoText);
 	infoText = 
 			saveAct->toolTip().prepend(tr("Save project"));
@@ -748,33 +749,39 @@ void MainWindowGUI::retranslateHelpText()
 
 void MainWindowGUI::newProject() 
 {
+  int save = 0;
 	bool b = DomainFacade::getFacade()->isUnsavedChanges();
 	if (b) {
-		int save = QMessageBox::question(this,
+		save = QMessageBox::question(this,
 			tr("Unsaved changes"),
 			tr("There are unsaved changes. Do you want to save?"),
-			tr("&Yes"), tr("&No"), // button 0, button 1, ...
-			QString::null, 0, 1 );
-		if (save == 0) { // user pressed button 0, which is 'yes'
+		        tr("&Save"), tr("Do&n't save"), tr("Abort"), 
+			0, 2 );
+		if (save == 0) { // user pressed button 0, which is 'save'
 			saveProject();
 		}
 	}
-	DomainFacade::getFacade()->newProject();
-	//fileMenu->setItemEnabled(SAVE, false);
-	saveAct->setEnabled(false);
+	if (save != 2) {
+	  DomainFacade::getFacade()->newProject();
+	  //fileMenu->setItemEnabled(SAVE, false);
+	  saveAct->setEnabled(false);
 	
-	DomainFacade::getFacade()->clearHistory();
-	modelSizeChanged(0);
-	toolsMenu->modelSizeChanged(0);
+	  DomainFacade::getFacade()->clearHistory();
+	  modelSizeChanged(0);
+	  toolsMenu->modelSizeChanged(0);
+	}
 }
 
 
 void MainWindowGUI::openProject()
 {
 	QString file = QFileDialog::
-		getOpenFileName(this, tr("Choose project file"), lastVisitedDir, "Stopmotion (*.sto)");
+		getOpenFileName(this,
+				tr("Choose project file"),
+				QString::fromLocal8Bit(lastVisitedDir),
+				"Stopmotion (*.sto)");
 	if ( !file.isNull() ) {
-		openProject( file.toLatin1().constData() );
+		openProject( file.toLocal8Bit().constData() );
 	}
 }
 
@@ -830,13 +837,15 @@ void MainWindowGUI::openThirdMostRecent()
 
 void MainWindowGUI::saveProjectAs()
 {
-	QString file = QFileDialog::
-		getSaveFileName(this, tr("Save As"), lastVisitedDir, "Stopmotion (*.sto)");
+	QString file = QFileDialog::getSaveFileName(this,
+			tr("Save As"),
+			QString::fromLocal8Bit(lastVisitedDir),
+			"Stopmotion (*.sto)");
 
 	if ( !file.isNull() ) {
 		DomainFacade::getFacade()->saveProject(file.toLocal8Bit());
-                QString path = QString::fromLocal8Bit(DomainFacade::getFacade()->getProjectPath());
-                path += QLatin1String("images/");
+		string path = DomainFacade::getFacade()->getProjectPath();
+		path += "images/";
 		changeMonitor->addDirectory(path);
 		//fileMenu->setItemEnabled(SAVE, true);
 		saveAct->setEnabled(true);
@@ -857,6 +866,31 @@ void MainWindowGUI::saveProject()
 }
 
 
+/* To be called instead of the default quit method */
+/* Checks whether the project is saved, and asks the user if not. */
+void MainWindowGUI::quitProgram()
+{
+        bool b = DomainFacade::getFacade()->isUnsavedChanges();
+        if (b) {
+                int save = QMessageBox::question(this,
+                                                 tr("Unsaved changes"),
+                                                 tr("There are unsaved changes. Do you want to save?"),
+                                                 tr("&Save"), tr("Do&n't save"), tr("Abort"),
+                                                 0, 2 );
+                if (save == 0) { // user pressed button 0, which is 'save'
+                        saveProject();
+                        exit(0); /* FIXME! Calling exit() is rather brutal. */
+                }
+                if (save == 1) { // user pressed button 1, which is "don't save"
+                  exit(0);
+                }
+        }
+        else {
+          exit(0);
+        }
+}
+
+
 void MainWindowGUI::exportToVideo()
 {
 	PreferencesTool *prefs = PreferencesTool::get();
@@ -876,7 +910,7 @@ void MainWindowGUI::exportToVideo()
 	}
 	else {
 		bool isCanceled = false;
-		char tmp[256];
+		char tmp[PATH_MAX];
 		VideoEncoder enc;
 		
 		sprintf(tmp, "startEncoder%d", active);
@@ -897,12 +931,14 @@ void MainWindowGUI::exportToVideo()
 		const char *output = prefs->getPreference(tmp, "");	
 		if (strcmp(output, "") == 0) {
 			QString file = QFileDialog::
-				getSaveFileName(this, tr("Export to video file"), lastVisitedDir);
+				getSaveFileName(this,
+						tr("Export to video file"),
+						QString::fromLocal8Bit(lastVisitedDir));
 			if ( file.isEmpty() ) {
 				isCanceled = true;	
 			}
 			else {
-				enc.setOutputFile( file.toLatin1().constData() );
+				enc.setOutputFile( file.toLocal8Bit().constData() );
 			}
 		}
 		else {
@@ -932,10 +968,13 @@ void MainWindowGUI::exportToVideo()
 void MainWindowGUI::exportToCinerella()
 {
 	QString file = QFileDialog::
-		getSaveFileName(this, tr("Export to file"), lastVisitedDir, "Cinerella (*.XXX)");
+		getSaveFileName(this,
+				tr("Export to file"),
+				QString::fromLocal8Bit(lastVisitedDir),
+				"Cinerella (*.XXX)");
 	
 	if ( !file.isNull() ) {
-		DomainFacade::getFacade()->exportToCinerella( file.toLatin1().constData() );
+		DomainFacade::getFacade()->exportToCinerella( file.toLocal8Bit().constData() );
 	}
 }
 
@@ -1116,7 +1155,7 @@ void MainWindowGUI::updateMostRecentMenu()
 	if (strcmp(first, "") != 0) {
 		if (access(first, R_OK) == 0) {
 			mostRecentAct->setVisible(true);
-			mostRecentAct->setText(QString(first));
+			mostRecentAct->setText(QString::fromLocal8Bit(first));
 		}
 		xmlFree((xmlChar*)first);
 	}
@@ -1128,7 +1167,7 @@ void MainWindowGUI::updateMostRecentMenu()
 	if (strcmp(second, "") != 0) { 
 		if (access(second, R_OK) == 0) {
 			secondMostRecentAct->setVisible(true);
-			secondMostRecentAct->setText(QString(second));
+			secondMostRecentAct->setText(QString::fromLocal8Bit(second));
 		}
 		xmlFree((xmlChar*)second);
 	}
@@ -1140,7 +1179,7 @@ void MainWindowGUI::updateMostRecentMenu()
 	if (strcmp(third, "") != 0) {
 		if (access(third, R_OK) == 0) {
 			thirdMostRecentAct->setVisible(true);
-			thirdMostRecentAct->setText(QString(third));
+			thirdMostRecentAct->setText(QString::fromLocal8Bit(third));
 		}
 		xmlFree((xmlChar*)third);
 	}
