@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Bjoern Erik Nilsen & Fredrik Berg Kjoelstad     *
- *   bjoern.nilsen@bjoernen.com     & fredrikbk@hotmail.com                *
+ *   Copyright (C) 2005-2008 by Bjoern Erik Nilsen & Fredrik Berg Kjoelstad*
+ *   bjoern.nilsen@bjoernen.com & fredrikbk@hotmail.com                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -48,7 +48,7 @@ public:
 	 * @param argc the argc argument from the environment through main
 	 * @param argv argv the argv arguments from the environment through main
 	 */
-	QtFrontend(int argc, char **argv);
+	QtFrontend(int &argc, char **argv);
 	
 	/**
 	 * Deallocates allocated memory and sets the pointers to NULL.
