@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Bjoern Erik Nilsen & Fredrik Berg Kjoelstad     *
- *   bjoern.nilsen@bjoernen.com     & fredrikbk@hotmail.com                *
+ *   Copyright (C) 2005-2008 by Bjoern Erik Nilsen & Fredrik Berg Kjoelstad*
+ *   bjoern.nilsen@bjoernen.com & fredrikbk@hotmail.com                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -30,7 +30,8 @@
 #endif	
 #include <fcntl.h>
 #include <errno.h>
-
+#include <stdio.h>
+#include <cstring>
 
 // Help function for starting a new thread
 extern "C" void* startupThread(void *arg)
@@ -107,7 +108,7 @@ bool OSSDriver::initialize()
 	// This means that the call imidiately returns with a return value
 	audioFD = open(audioDevice, O_WRONLY | O_NONBLOCK, 0);
 	if (audioFD == -1 || audioFD == EBUSY) {
-		fprintf(stderr, "Cannot open device: %s\n", strerror(errno));
+		fprintf(stderr, "Cannot open device %s: %s\n", audioDevice, strerror(errno));
 		return false;
 	}
 	
