@@ -558,12 +558,12 @@ Dette kan settes i preferanse-menyen.</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="346"/>
-        <source>Start deamon</source>
+        <source>Start daemon</source>
         <translation>Start nisse</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="347"/>
-        <source>Stop deamon</source>
+        <source>Stop daemon</source>
         <translation>Stopp nisse</translation>
     </message>
     <message>
@@ -948,7 +948,7 @@ Dette kan settes i preferanse-menyen.</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="571"/>
-        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automaticly be saved to the previously selected file.&lt;/p&gt;</source>
+        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automatically be saved to the previously selected file.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Lagre&lt;/h4&gt;&lt;p&gt;&lt;em&gt;Lagrer&lt;/em&gt; nåværende animasjon som en Stopmotion prosjektfil. &lt;BR&gt; Hvis prosjektet allerede er lagret til fil, vil det automatisk lagre til denne filen. &lt;/p&gt;</translation>
     </message>
     <message>
@@ -1265,12 +1265,12 @@ to check your settings in the preferences menu?</source>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="230"/>
-        <source>vgrabbj VGA deamon</source>
-        <translation>vgrabbj VGA deamon</translation>
+        <source>vgrabbj VGA daemon</source>
+        <translation>vgrabbj VGA daemon</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="232"/>
-        <source>Starts vgrabbj as a deamon. Pretty fast.</source>
+        <source>Starts vgrabbj as a daemon. Pretty fast.</source>
         <translation>Starter vgrabbj som en nisse. Veldig kjapt.</translation>
     </message>
     <message>
@@ -1545,8 +1545,8 @@ lagret som ~/.stopmotion/preferences.xml.OLD)</translation>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="411"/>
         <source>Playback only currently works when running the grabber 
-as a deamon. Go to the preferences menu (CTRL+P) to switch 
-to running the image grabbing as a deamon.</source>
+as a daemon. Go to the preferences menu (CTRL+P) to switch 
+to running the image grabbing as a daemon.</source>
         <translation>Playback fungerer kun når du gjører bildefangst-programmet som 
 en nisse. Gå til preferansemenyen (CTRL+P ) for å sette at 
 programmet skal kjøres som en nisse.</translation>
